pub fn look_at_affine3a(eye: Vec3, center: Vec3, up: Vec3) -> Affine3AExpand description
Returns an Affine3A view transform from eye, focal point, and up.
Transforms left-handed world space points into left-handed Y-up view space.
Panics
Will panic if up is not normalized when glam_assert is enabled.